/*
    uart programmer for Cypress PSoC.
    PSoC bootloader commands.
    Copyright (C) 2015  Michael Stickel (michael@cubic.org)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef DEFINED_PSOC_UART_PROGRAMMER_COMMANDS
#define DEFINED_PSOC_UART_PROGRAMMER_COMMANDS

enum PsocErrorCode
{
    CYRET_SUCCESS = 0x00, /* The command was successfully received and executed. */
    BOOTLOADER_ERR_VERIFY = 0x02, /* The verification of flash failed */
    BOOTLOADER_ERR_LENGTH = 0x03, /* The amount of data available is outside the expected range */
    BOOTLOADER_ERR_DATA = 0x04, /* The data is not of the proper form */
    BOOTLOADER_ERR_CMD = 0x05, /* The command is not recognized. */
    BOOTLOADER_ERR_DEVICE = 0x06, /* The expected device does not match the detected device. */
    BOOTLOADER_ERR_VERSION = 0x07, /* The bootloader version detected is not supported. */
    BOOTLOADER_ERR_CHECKSUM = 0x08, /* The checksum does not match the expected value. */
    BOOTLOADER_ERR_ARRAY = 0x09, /* The flash array ID is not valid. */
    BOOTLOADER_ERR_ROW = 0x0A, /* The flash row number is not valid. */
    BOOTLOADER_ERR_APP = 0x0C, /* The application is not valid and cannot be set as active */
    BOOTLOADER_ERR_ACTIVE = 0x0D, /* The application is currently marked as active. */
    BOOTLOADER_ERR_UNK = 0x0F /* An unknown error occurred. */
};

int PsocVerifyChecksum();
int PsocGetFlashSize(const int _flashArrayId, int * _firstRowNumber, int * _lastRowNumber);
int PsocGetApplicationStatus(const int _applicationNumber, int * _validApplicationNumber,  int * _activeApplicationNumber);
int PsocEraseRow (const unsigned int _flashArrayId, const unsigned int _rowNumber);
int PsocSyncBootloader();
int PsocSetActiveApplication(const unsigned int _applicationNumber);
int PsocSendData(const unsigned char * _data, const unsigned int _size);
int PsocEnterBootloader (unsigned long * _siliconId, unsigned char * _siliconRev, int * _bootloaderVersion);
int PsocProgramRow(const unsigned int _flashArrayId, const unsigned int _rowNumber, const unsigned char * _data, const unsigned int _size);
int PsocVerifyRow(const unsigned int _flashArrayId, const unsigned int _rowNumber, unsigned int * _checksum);
void PsocExitBootloader(void);
int PsocOpenPort(const char * _deviceFilename);

#endif // 
